@@ -165,12 +165,17 @@ calc_derivative
 plotgeometry
 plotnormals
 eulersolve
+resolve
+aic_memory_clean
 '''
 
-paneller.Solid.__init__.__doc__='''__init__(sldlist=[], wraparounds=[], full_parallel=False): instantiate solid, adding the first patches as their matrixes of point arrays are inserted in list sldlist, 
+paneller.Solid.__init__.__doc__='''__init__(sldlist=[], wraparounds=[], full_parallel=False): instantiate solid, adding the first patches as their matrixes of point arrays 
+are inserted in list sldlist, 
 and their wrapping directions are in the list of lists wraparounds. Ex. sldlist=[mat], wraparounds=[[1]] indicates a patch mat is to be first inserted, with the lines in the first row of mat
-being considered the same as those of the last row. wraparounds=[[0]] would do the same with first and last columns in \'mat\' matrix.
-If flag full_parallel is selected, parallel execution of aicm calculations will be held so as to stop recursive multiprocessing on windows. This is necessary when parallelizing the whole analysis operation'''
+being considered the same as those of the last row. wraparounds=[[0]] would do the same with first and last columns in \'mat\' matrix. 
+If flag full_parallel is selected, parallel execution of aicm calculations will be held so as to stop recursive multiprocessing on Windows. This is necessary when parallelizing the whole analysis 
+(not just AIC matrix calculation which is parallelized by default)
+so as not to generate child processes recursively'''
 paneller.Solid.addpatch.__doc__='''addpatch(sld, wraps=[], prevlines={}, invlats=[], tolerance=5e-5): add patch with point array matrix (list of lists) sld. prevlines indicates indexes of previously
 created lines to be used as edges for points in the first (key \'low\') or last (key \'up\') rows or columns (\'right\' and \'left\' keys).
 invlats contains the previously cited keys for laterals which should have its lines inverted when being added to panels. wraps contains wraparound commands as axis indexes, as described in reference
@@ -241,6 +246,11 @@ paneller.Solid.PG_remove.__doc__='''PG_remove(beta, a, b): reverses effects from
 paneller.Solid.wake_aicm_recalc.__doc__='''wake_aicm_recalc(): recalculates wake line aerodynamic influence coefficients based on wake redefinition previously applied by Solid.wake_redef()'''
 paneller.Solid.wake_redef.__doc__='''wake_redef(Uinf=1.0, a=0.0, b=0.0): redefines wake line geometries to fit new definitions of freestream parameters'''
 paneller.Solid.velcompute.__doc__='''velcompute(): computes velocity field on panel collocation points across the solid'''
+paneller.Solid.resolve.__doc__='''resolve(self, target=np.array([]), Uinf=1.0, M=0.0, gamma=1.4, beta=1.0, a=0.0, b=0.0, p=0.0, q=0.0, r=0.0, damper=0.0, echo=True, wakeiter=0, tolerance=1e-5): 
+recomputes complete euler solution through calls for 
+Solid.genvbar, gennvv, wake_aicm_recalc (to fit new freestream parameters), solve, calcpress and calcforces. Uses given freestream parameters and outputs time duration report if echo==True. 
+Applies PG correction factor beta. M and gamma used for Cp compressibility corrections.'''
+paneller.Solid.aic_memory_clean.__doc__='''aic_memory_clean(): deletes and garbage-collects aic matrixes (up to 80%% of program's total memory usage)'''
 
 utils.__doc__='''
 Module containing geometry processing, list trimming and other utilities for other modules
