@@ -10,6 +10,7 @@ import scipy.sparse as sps
 import time as tm
 import multiprocessing as mp
 import os
+import gc
 
 import pytoolkit
 from utils import *
@@ -49,7 +50,7 @@ class WakePanel:
 
 class Solid:
     def __init__(self, sldlist=[], wraparounds=[], full_parallel=False): #solid data type
-        if (not full_parallel) and mp.current_process().name != 'MainProcess':
+        if ((not full_parallel) and mp.current_process().name == 'LPM_child'):
             self.runme=False
         else:
             self.runme=True
@@ -400,33 +401,32 @@ class Solid:
         for i in range(len(self.panels)):
             colmat[i, :]=self.panels[i].colpoint
             nvectmat[i, :]=self.panels[i].nvector
-        ncpus=mp.cpu_count()
-        calclims=np.linspace(0, self.nlines, ncpus+1)
-        calclims=[int(c) for c in calclims]
-        calclims=[[calclims[i], calclims[i+1]] for i in range(ncpus)]
-        queue1=mp.Queue()
-        queue2=mp.Queue()
-        for i in range(len(calclims)):
-            self.addorder(queue1, colmat, ind1=calclims[i][0], ind2=calclims[i][1])
         if not self.full_parallel:
+            ncpus=mp.cpu_count()
+            calclims=np.linspace(0, self.nlines, ncpus+1)
+            calclims=[int(c) for c in calclims]
+            calclims=[[calclims[i], calclims[i+1]] for i in range(ncpus)]
+            queue1=mp.Queue()
+            queue2=mp.Queue()
+            for i in range(len(calclims)):
+                self.addorder(queue1, colmat, ind1=calclims[i][0], ind2=calclims[i][1])
             processes=[]
             for i in range(ncpus):
-                processes+=[mp.Process(target=subprocess_genaicm, args=(queue1, queue2))]
+                processes+=[mp.Process(target=subprocess_genaicm, args=(queue1, queue2), name='LPM_child')]
             for p in processes:
                 p.start()
+            ordresults=[]
+            for i in range(ncpus):
+                ordresults+=[queue2.get()]
+            if not self.full_parallel:
+                for p in processes:
+                    p.join()
+            self.aicm3_line=np.zeros((3, self.npanels, self.nlines))
+            for ordresult in ordresults:
+                self.aicm3_line[:, :, ordresult[0]:ordresult[1]]=ordresult[2]
         else:
             print('NOTICE: running LovelacePM without parallel AICM calculation')
-            for i in range(ncpus):
-                subprocess_genaicm(queue1, queue2)
-        ordresults=[]
-        for i in range(ncpus):
-            ordresults+=[queue2.get()]
-        if not self.full_parallel:
-            for p in processes:
-                p.join()
-        self.aicm3_line=np.zeros((3, self.npanels, self.nlines))
-        for ordresult in ordresults:
-            self.aicm3_line[:, :, ordresult[0]:ordresult[1]]=ordresult[2]
+            self.aicm3_line=pytoolkit.aicm_lines_gen(self.lines, colmat)
         self.gen_panline()
         self.aicm3=np.zeros((3, self.npanels, self.npanels))
         for i in range(3):
@@ -756,7 +756,7 @@ class Solid:
             plt.ylabel('y')
             plt.show()
     def eulersolve(self, target=np.array([]), Uinf=1.0, M=0.0, gamma=1.4, beta=1.0, a=0.0, b=0.0, p=0.0, q=0.0, r=0.0, damper=0.0, echo=True, \
-        wakeiter=0, tolerance=1e-5):
+        wakeiter=0, tolerance=1e-5, aic_memory_clean=False):
         if self.runme:
             if echo:
                 print('========Euler solution=======')
@@ -808,6 +808,10 @@ class Solid:
             if echo:
                 print('Solution and post-processing: '+str(tm.time()-t)+' s')
                 print('=============================')
+    def aic_memory_clean(self): #garbage-collect memory from AIC matrixes, which can be, with this method, deleted after calculations
+        if self.runme:
+            del self.aicm, self.iaicm, self.aicm3, self.aicm3_line
+            gc.collect()
 
 '''sld=Solid(sldlist=[np.array([[0.0, 0.0, 0.0], [1.0, 0.0, 0.0], [1.0, 1.0, 0.0], [0.0, 1.0, 0.0]]).T])
 #sld.plotgeometry()
